@@ -95,7 +95,19 @@ NULL
 #' @description
 #' Linters that evaluate parts of the linted code, such as loading referenced packages.
 #' These linters should not be used with untrusted code, and may need dependencies of the linted package or project to
-#' be available in order to function correctly.
+#' be available in order to function correctly. For package authors, note that this includes loading the package itself,
+#'   e.g. with `pkgload::load_all()` or installing and attaching the package.
 #' @evalRd rd_linters("executing")
 #' @seealso [linters] for a complete list of linters available in lintr.
 NULL
+
+#' Testthat linters
+#' @name pkg_testthat_linters
+#' @description
+#' Linters encouraging best practices within testthat suites.
+#' @evalRd rd_linters("pkg_testthat")
+#' @seealso
+#'  - [linters] for a complete list of linters available in lintr.
+#'  - <https://testthat.r-lib.org>
+#'  - <https://r-pkgs.org/testing-basics.html>
+NULL
